"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const network_1 = require("../../base/network");
class GetCommand extends network_1.NetworkCommand {
    async run() {
        const { args, flags } = this.parse(GetCommand);
        let networkUrl;
        try {
            networkUrl = this.getNetworkUrl(flags);
            const { abi, event, address } = args;
            const { getEvents } = await Promise.resolve().then(() => __importStar(require('../../helpers/getEvents')));
            const { getBlockNumber } = await Promise.resolve().then(() => __importStar(require('../../helpers/getBlockNumber')));
            let fromBlock = await getBlockNumber(networkUrl);
            while (true) {
                const toBlock = await getBlockNumber(networkUrl);
                if (fromBlock <= toBlock) {
                    const events = await getEvents(abi, event, address, networkUrl, {
                        from: fromBlock,
                        to: toBlock,
                    });
                    events.forEach(event => this.log(event));
                    fromBlock = toBlock + 1;
                }
                await new Promise((res) => setTimeout(res, 5000));
            }
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
exports.default = GetCommand;
GetCommand.description = `Emit new events from the given type in the given contract`;
GetCommand.flags = Object.assign({}, network_1.NetworkCommand.flags);
GetCommand.args = [
    {
        name: 'abi',
        required: true,
        description: `The contract's ABI.`,
    },
    {
        name: 'event',
        required: true,
        description: `e.g.: 'MyEvent'`,
    },
    {
        name: 'address',
        required: true,
        description: `The contract's  address.`,
    },
];
GetCommand.examples = [
    'eth event:get --mainnet --from 1 erc20 Transfer 0x89d24a6b4ccb1b6faa2625fe562bdd9a23260359',
];
