"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const web3_1 = tslib_1.__importDefault(require("web3"));
const config_1 = require("./config");
const utils_1 = require("./utils");
async function getEvents(abiPath, eventName, name, url, { from, to }) {
    const abi = utils_1.loadABI(abiPath);
    const matchingEvents = utils_1.extractMethodsAndEventsFromABI(abi).filter(x => x.name === eventName);
    if (!matchingEvents.length) {
        throw new Error('[getEvents] event specified does not exist in the ABI provided');
    }
    const eventAbi = matchingEvents[0];
    const web3 = new web3_1.default(new web3_1.default.providers.HttpProvider(url));
    const networkId = await web3.eth.net.getId();
    const address = config_1.getAddress(name, String(networkId));
    const contract = new web3.eth.Contract(abi, address);
    const events = await contract.getPastEvents(eventName, { fromBlock: from, toBlock: to });
    const parsedEvents = events.map(event => {
        const returnValues = eventAbi.inputs.map((x, i) => event.returnValues[i]).join(',');
        return `${eventAbi.name}(${returnValues})`;
    });
    return parsedEvents;
}
exports.getEvents = getEvents;
